Color conversions and types.
If you want a compact color representation, use Color32Bit.
If you want to manipulate RGBA colors use ColorLinear.
If you want to manipulate colors in a way closer to how humans think about colors, use ColorHsvaGamma.
Feature flags
extra_debug_asserts— Enable additional checks if debug assertions are enabled (debug builds).extra_asserts— Always enable additional checks.
Optional dependencies
Structs
- Color32
Bit - This format is used for space-efficient color representation (32 bits).
- Color
Hsva - Hue, saturation, value, alpha. All in the range [0, 1]. No premultiplied alpha.
- Color
Hsva Gamma - Like Hsva but with the
vvalue (brightness) being gamma corrected so that it is somewhat perceptually even. - Color
Linear - 0-1 linear space
RGBAcolor with premultiplied alpha.
Traits
Functions
- gamma_
from_ linear - linear [0, 1] -> gamma [0, 1] (not clamped). Works for numbers outside this range (e.g. negative numbers).
- gamma_
u8_ from_ linear_ f32 - linear [0, 1] -> gamma [0, 255] (clamped). Values outside this range will be clamped to the range.
- hsv_
from_ rgb - All ranges in 0-1, rgb is linear.
- linear_
f32_ from_ gamma_ u8 - gamma [0, 255] -> linear [0, 1].
- linear_
f32_ from_ linear_ u8 - linear [0, 255] -> linear [0, 1]. Useful for alpha-channel.
- linear_
from_ gamma - gamma [0, 1] -> linear [0, 1] (not clamped). Works for numbers outside this range (e.g. negative numbers).
- linear_
u8_ from_ linear_ f32 - linear [0, 1] -> linear [0, 255] (clamped). Useful for alpha-channel.
- rgb_
from_ hsv - All ranges in 0-1, rgb is linear.